/*
# Copyright (c) 2017 LINE Corporation
# These sources are released under the terms of the MIT license: see LICENSE
*/

/* https://stackoverflow.com/questions/5379752/css-style-external-links */
a[rel]:after {
  content: " " url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAVklEQVR4Xn3PgQkAMQhDUXfqTu7kTtkpd5RA8AInfArtQ2iRXFWT2QedAfttj2FsPIOE1eCOlEuoWWjgzYaB/IkeGOrxXhqB+uA9Bfcm0lAZuh+YIeAD+cAqSz4kCMUAAAAASUVORK5CYII=);
}

.auto-grid {
  display: grid;
  grid-gap: 10px;
  grid-template-columns: repeat(auto-fit, minmax(200px,1fr));
}

.service-grid {
  display: grid;
  grid-gap: 10px;
  grid-template-columns: repeat(auto-fit, minmax(400px,1fr));
}

[v-cloak] {
  display: none;
}

.dl-horizontal {
  word-wrap: break-word;
}

/* https://stackoverflow.com/a/30702646 */

.navbar-brand {
  padding: 0px; /* firefox bug fix */
}
.navbar-brand>img {
  height: 100%;
  padding: 5px; /* firefox bug fix */
  width: auto;
}

.promgen-disabled {
  text-decoration: line-through;
  color: #777;
  opacity: 0.65;
}

.promgen-clause {
  word-break: break-word;
  font-family: monospace;
}
