# Generated by Django 2.2.10 on 2020-03-16 09:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('promgen', '0018_default_exporter_scheme'),
    ]

    operations = [
        migrations.AddField(
            model_name='sender',
            name='enabled',
            field=models.BooleanField(default=True),
        ),
    ]
