# Generated by Django 2.2.8 on 2020-02-28 06:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('promgen', '0016_alertlabel'),
    ]

    operations = [
        migrations.AlterField(
            model_name='alertlabel',
            name='value',
            field=models.TextField(),
        ),
    ]
