# Generated by Django 2.0.7 on 2018-09-05 02:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('promgen', '0003_alert_queue'),
        ('promgen', '0003_default-group'),
    ]

    operations = [
    ]
