{% load i18n %}

<h2>
    <a href="{% url 'service-detail' service.id %}">{{ service.name }}</a>
    {% if service.owner %}
    <small class="pull-right">{% trans 'Contact' %}: {{service.owner.username}}</small>
    {% endif %}
</h2>
