# Generated by Django 2.2.10 on 2020-02-14 05:41


import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('promgen', '0012_validation_updates'),
    ]

    operations = [
        migrations.AlterField(
            model_name='farm',
            name='name',
            field=models.CharField(max_length=128, validators=[django.core.validators.RegexValidator('^[\\w][- \\w]+\\Z', 'Unicode letters, numbers, underscores, or hyphens or spaces')]),
        ),
        migrations.AlterField(
            model_name='project',
            name='name',
            field=models.CharField(max_length=128, unique=True, validators=[django.core.validators.RegexValidator('^[\\w][- \\w]+\\Z', 'Unicode letters, numbers, underscores, or hyphens or spaces')]),
        ),
        migrations.AlterField(
            model_name='rule',
            name='name',
            field=models.CharField(max_length=128, unique=True, validators=[django.core.validators.RegexValidator('[a-zA-Z_:][a-zA-Z0-9_:]*', 'Only alphanumeric characters are allowed.')]),
        ),
        migrations.AlterField(
            model_name='service',
            name='name',
            field=models.CharField(max_length=128, unique=True, validators=[django.core.validators.RegexValidator('^[\\w][- \\w]+\\Z', 'Unicode letters, numbers, underscores, or hyphens or spaces')]),
        ),
        migrations.AlterField(
            model_name='shard',
            name='name',
            field=models.CharField(max_length=128, unique=True, validators=[django.core.validators.RegexValidator('^[\\w][- \\w]+\\Z', 'Unicode letters, numbers, underscores, or hyphens or spaces')]),
        ),
    ]
