# Generated by Django 2.2.10 on 2020-02-21 05:56

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('promgen', '0014_exporter_scheme'),
    ]

    operations = [
        migrations.AlterField(
            model_name='rule',
            name='content_type',
            field=models.ForeignKey(limit_choices_to=models.Q(models.Q(('app_label', 'promgen'), ('model', 'site')), models.Q(('app_label', 'promgen'), ('model', 'project')), models.Q(('app_label', 'promgen'), ('model', 'service')), _connector='OR'), on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType'),
        ),
        migrations.AlterField(
            model_name='sender',
            name='content_type',
            field=models.ForeignKey(limit_choices_to=models.Q(models.Q(('app_label', 'auth'), ('model', 'user')), models.Q(('app_label', 'promgen'), ('model', 'project')), models.Q(('app_label', 'promgen'), ('model', 'service')), _connector='OR'), on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType'),
        ),
    ]
