{% load i18n %}
<tr>
    <td><a href="{{project.get_absolute_url}}">{{ project.name }}</a></td>

    <td>
        <table style="width: 100%">
            {% for exporter in project.exporter_set.all %}
            <tr {% if not exporter.enabled %}class="promgen-disabled" {% endif %}>
                <td>{{ exporter.job }}</td>
                <td>{{ exporter.port }}</td>
                <td>{{ exporter.path }}</td>
            </tr>
            {% empty %}
            <tr>
                <td colspan="3">
                    <a href="{% url 'project-exporter' project.id %}" class="btn btn-primary btn-xs">{% trans "Register Exporter" %}</a>
                </td>
            </tr>
            {% endfor %}
        </table>
    </td>

    <td>
        <table style="width: 100%">
            {% for notifier in project.notifiers.all %}
            <tr>
                <td title="Added by: {{notifier.owner}}">{{ notifier.sender }}</td>
                <td>{{ notifier.show_value }}</td>
            </tr>
            {% empty %}
            <tr>
                <td colspan="2">
                    <a href="{% url 'project-notifier' project.id %}" class="btn btn-primary btn-xs">{% trans "Register Notifier" %}</a>
                </td>
            </tr>
            {% endfor %}
        </table>
    </td>

    <td>
        <a @click="setSilenceDataset" class="btn btn-warning btn-xs" data-project="{{project.name}}" data-service="{{service.name}}">{% trans "Silence" %}</a>
    </td>
</tr>
