{% extends "rest_framework/base.html" %}

{# See
https://github.com/tomchristie/django-rest-framework/blob/master/rest_framework/templates/rest_framework/base.html #}

{% load static %}

{% block title %}Promgen {{ VERSION }}{% endblock %}
{% block navbar %}{% include "promgen/navbar.html" %}{% endblock %}

{% block bootstrap_theme %}
<link rel="stylesheet" href="{% static 'css/bootstrap.min.css' %}">
<link rel="stylesheet" href="{% static 'css/bootstrap-theme.min.css' %}">
<link rel="stylesheet" href="{% static 'css/bootstrap-switch.min.css' %}">
<link rel="stylesheet" href="{% static 'css/promgen.css' %}">
<link rel="icon" href="{% static 'images/promgen_logo_color.png' %}">
{% endblock %}

{% block script %}
<script>
    window.drf = {
        csrfHeaderName: "{{ csrf_header_name|default:'X-CSRFToken' }}",
        csrfToken: "{% if request %}{{ csrf_token }}{% endif %}"
    };
</script>

<script src="{% static 'js/jquery.min.js' %}"></script>
<script src="{% static 'js/bootstrap.min.js' %}"></script>
<script src="{% static 'js/luxon.min.js' %}"></script>

<script src="{% static 'rest_framework/js/ajax-form.js' %}"></script>
<script src="{% static 'rest_framework/js/csrf.js' %}"></script>
<script src="{% static 'rest_framework/js/prettify-min.js' %}"></script>
<script src="{% static 'rest_framework/js/default.js' %}"></script>

<script>
    $(document).ready(function () {
        $('form').ajaxForm();
    });
</script>
{% endblock %}
