# Generated by Django 2.2.10 on 2020-03-31 05:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('promgen', '0019_sender_enabled'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='exporter',
            unique_together={('job', 'port', 'path', 'scheme', 'project')},
        ),
    ]
