<li class="dropdown">
    <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="false">Help <span class="caret"></span></a>
    <ul class="dropdown-menu">
        <li><a rel="noopener noreferrer" href="https://line.github.io/promgen/">Documentation</a></li>
        <li><a rel="noopener noreferrer" href="https://github.com/line/promgen/releases">Changelog</a></li>
    </ul>
</li>
