{% for error in warning %}
<div class="alert alert-warning alert-dismissible" role="alert">
    <span class="glyphicon glyphicon-alert" aria-hidden="true"></span>
    <span class="sr-only">Warning:</span>
    <button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>
    {{error}}
</div>
{% endfor %}
{% for error in danger %}
<div class="alert alert-danger alert-dismissible" role="alert">
    <span class="glyphicon glyphicon-alert" aria-hidden="true"></span>
    <span class="sr-only">Warning:</span>
    <button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>
    {{error}}
</div>
{% endfor %}
