{% load i18n %}

<td class="col-xs-1">
    <a :href="alert.generatorURL">[[time(alert.startsAt)]]</a>
</td>
<td>
    <dl class="dl-horizontal">
        <dt>Labels</dt>
        <dd>
            <ul class="list-inline">
                <li v-for="(value, label) in alert.labels">
                    <a @click="addSilenceLabel(label, value)" class="label label-danger">[[label]]:[[value]]</a>
                </li>
            </ul>
        </dd>
        <template v-for="(value, annotation) in alert.annotations" class="dl-horizontal">
            <dt>[[annotation]]</dt>
            <dd v-html="urlize(value)"></dd>
        </template>
    </dl>
</td>
<td>
    <a @click="setSilenceLabels(alert.labels)" class="btn btn-warning btn-xs">{% trans "Silence" %}</a>
</td>
