<bootstrap-panel v-if="show" class="panel-info" heading="Results">
  <table class="table">
    <tr v-for="(val, key, index) in store.results">
      <td>[[ key ]]</td>
      <td>[[ val ]]</td>
    </tr>
  </table>
</bootstrap-panel>
