{% extends "base.html" %}
{% load i18n %}
{% load promgen %}

{% block content %}

<div class="page-header">
  <h1>{% trans 'Services' %}</h1>
  <a href="{% url 'service-new'  %}" class="btn btn-primary btn-sm float-right">{% trans "Register Service" %}</a>
</div>

{% breadcrumb label="Services" %}

{% include "promgen/pagination.html" %}

{% for service in service_list %}
{% include "promgen/service_header.html" %}
{% include "promgen/service_block.html" %}
{% endfor %}

{% include "promgen/pagination.html" %}

{% endblock %}
