{% load i18n %}
<td class="col-xs-1">[[time(silence.startsAt)]]</td>
<td class="col-xs-1">[[time(silence.endsAt)]]</td>
<td class="col-xs-3 text-wrap">
    <ul class="list-inline">
        <li v-for="match in silence.matchers">
            <a @click="addSilenceLabel(match.name, match.value)" class="label label-warning">
                [[match.name]]:[[match.value]]
            </a>
        </li>
    </ul>
</td>
<td class="col-xs-3" v-html="urlize(silence.comment)"></td>
<td class="col-xs-3">[[silence.createdBy]]</td>

<td style="col-xs-1">
    <a @click="expireSilence(silence.id)" class="btn btn-warning btn-xs">{% trans "Expire" %}</a>
</td>
